@@ -29,7 +29,7 @@ if not valid_version:  # pragma: no cover
     sys.exit()
 
 del valid_version
-__version__ = "0.3.153"
+__version__ = "0.4.6"
 
 
 # ===========================================
@@ -41,6 +41,7 @@ from friendly_traceback import editors_helpers, set_stream
 from friendly_traceback import set_formatter as ft_set_formatter
 from friendly_traceback.config import session
 from friendly_traceback import exclude_directory_from_traceback
+from friendly_traceback import set_lang as ft_set_lang
 
 from .my_gettext import current_lang
 from friendly import rich_formatters, theme
@@ -112,6 +113,7 @@ def run(
             return
 
     session.install(lang=lang, include=include, redirect=redirect)
+    set_lang(lang)
     session.set_formatter(formatter)
 
     module_globals = editors_helpers.exec_code(
@@ -138,6 +140,7 @@ def set_formatter(
     """
     session.rich_add_vspace = True
     session.use_rich = True
+    session.jupyter_button_style = ""
     if formatter in ["dark", "light"]:
         session.console = theme.init_rich_console(
             style=formatter,
@@ -147,6 +150,25 @@ def set_formatter(
         )
         set_stream(redirect=rich_formatters.rich_writer)
         formatter = rich_formatters.rich_markdown
+    elif formatter == "interactive-dark":
+        session.console = theme.init_rich_console(
+            style="dark",
+            color_system=color_system,
+            force_jupyter=force_jupyter,
+            background=background,
+        )
+        formatter = rich_formatters.jupyter_interactive
+        session.jupyter_button_style = ";color: white; background-color:black;"
+        set_stream()
+    elif formatter == "interactive":
+        session.console = theme.init_rich_console(
+            style="light",
+            color_system=color_system,
+            force_jupyter=force_jupyter,
+            background=background,
+        )
+        formatter = rich_formatters.jupyter_interactive
+        set_stream()
     else:
         session.use_rich = False
         set_stream()
@@ -176,3 +198,8 @@ def start_console(  # pragma: no cover
         displayhook=displayhook,
         ipython_prompt=ipython_prompt,
     )
+
+
+def set_lang(lang):
+    ft_set_lang(lang)
+    current_lang.install(lang)
