@@ -25,6 +25,7 @@ from pygments import highlight  # noqa
 from pygments.lexers import PythonLexer, PythonTracebackLexer  # noqa
 from pygments.formatters import HtmlFormatter  # noqa
 
+from rich import jupyter as rich_jupyter
 
 ipython_available = False
 try:  # pragma: no cover
@@ -35,13 +36,146 @@ try:  # pragma: no cover
 except ImportError:
     display = HTML = lambda x: x
 
-RICH_HEADER = False
+RICH_HEADER = False  # not a constant
+COUNT = 0  # not a constant
+
+
+def jupyter_interactive(info, include="friendly_tb"):  # noqa
+    """Work in progress to experiment creating interactive tracebacks
+    in Jupyter notebooks"""
+    global COUNT
+    if include != "friendly_tb":
+        text = _markdown(info, include=include, rich=True)
+        rich_writer(text)
+        return
+    COUNT += 1
+    _ = current_lang.translate
+    session.rich_add_vspace = False
+    add_message(info, count=COUNT)
+    add_control(count=COUNT)
+    add_friendly_tb(info, count=COUNT)
+    add_interactive_item(info, "what", count=COUNT)
+    add_interactive_item(info, "why", count=COUNT)
+    add_interactive_item(info, "where", count=COUNT)
+    return ""
+
+
+def add_message(info, count=-1):
+    old_jupyter_html_format = rich_jupyter.JUPYTER_HTML_FORMAT
+    rich_jupyter.JUPYTER_HTML_FORMAT = (
+        "<div id='friendly-message{count}'>".format(count=COUNT)
+        + old_jupyter_html_format
+        + "</div>"
+    )
+    text = _markdown(info, include="message", rich=True)
+    rich_writer(text)
+    rich_jupyter.JUPYTER_HTML_FORMAT = old_jupyter_html_format
+
+
+def add_friendly_tb(info, count=-1):
+    old_jupyter_html_format = rich_jupyter.JUPYTER_HTML_FORMAT
+    name = "friendly_tb"
+    rich_jupyter.JUPYTER_HTML_FORMAT = (
+        "<div id='friendly-tb-{name}-content{count}' style='display:none'>".format(
+            name=name, count=count
+        )
+        + old_jupyter_html_format
+        + "</div>"
+    )
+    text = _markdown(info, include="friendly_tb", rich=True)
+    rich_writer(text)
+    rich_jupyter.JUPYTER_HTML_FORMAT = old_jupyter_html_format
+
+
+def add_interactive_item(info, name, count=-1):
+    _ = current_lang.translate
+    old_jupyter_html_format = rich_jupyter.JUPYTER_HTML_FORMAT
+
+    content = """<script> function toggle_{name}{count}(){{
+     var content = document.getElementById('friendly-tb-{name}-content{count}');
+     var btn = document.getElementById('friendly-tb-btn-show-{name}{count}');
+        if (content.style.display === 'none') {{
+            content.style.display = 'block';
+            btn.textContent = "{hide} {name}()";
+        }} else {{
+            content.style.display = 'none';
+            btn.textContent = "{name}()";
+       }}
+    }}
+     </script>
+     <button id='friendly-tb-btn-show-{name}{count}' onclick='toggle_{name}{count}()' style='display:none {btn_style}'>
+     {name}()
+     </button>
+    """.format(
+        name=name, count=count, hide=_("Hide"), btn_style=session.jupyter_button_style
+    )
+    display(HTML(content))
+
+    rich_jupyter.JUPYTER_HTML_FORMAT = (
+        "<div id='friendly-tb-{name}-content{count}' style='display:none'>".format(
+            name=name, count=count
+        )
+        + old_jupyter_html_format
+        + "</div>"
+    )
+    text = _markdown(info, include=name, rich=True)
+    rich_writer(text)
+
+    rich_jupyter.JUPYTER_HTML_FORMAT = old_jupyter_html_format
+
+
+def add_control(count=-1):
+    _ = current_lang.translate
+    content = """
+        <button id='friendly-tb-btn-show{count}' onclick='friendly_toggle_more{count}()' style='{btn_style}'>
+        {more}
+        </button>
+        <script> function friendly_toggle_more{count}(){{
+        var btn = document.getElementById('friendly-tb-btn-show{count}');
+        var btn_what = document.getElementById('friendly-tb-btn-show-what{count}');
+        var btn_where = document.getElementById('friendly-tb-btn-show-where{count}');
+        var btn_why = document.getElementById('friendly-tb-btn-show-why{count}');
+        var message = document.getElementById('friendly-message{count}');
+        var friendly_tb_content = document.getElementById('friendly-tb-friendly_tb-content{count}');
+        var what_content = document.getElementById('friendly-tb-what-content{count}');
+        var why_content = document.getElementById('friendly-tb-why-content{count}');
+        var where_content = document.getElementById('friendly-tb-where-content{count}');
+
+        if (btn_what.style.display == 'none'){{
+            message.style.display = 'none';
+            btn_what.style.display = 'block';
+            btn_why.style.display = 'block';
+            btn_where.style.display = 'block';
+            friendly_tb_content.style.display = 'block';
+            btn.textContent = "{only}";
+        }} else {{
+            btn_what.style.display = 'none';
+            btn_what.textContent = 'what()';
+            btn_why.style.display = 'none';
+            btn_why.textContent = 'why()';
+            btn_where.style.display = 'none';
+            btn_where.textContent = 'where()';
+            what_content.style.display = 'none';
+            why_content.style.display = 'none';
+            where_content.style.display = 'none';
+            friendly_tb_content.style.display = 'none';
+            message.style.display = 'block';
+            btn.textContent = "{more}";
+        }}
+        }};
+        </script>
+        """.format(
+        count=count,
+        more=_("More ..."),
+        only=_("Show message only"),
+        btn_style=session.jupyter_button_style,
+    )
+    display(HTML(content))
 
 
 def rich_writer(text):  # pragma: no cover
     """Default writer"""
     global RICH_HEADER
-
     if session.rich_add_vspace:
         session.console.print()
     md = theme.friendly_rich.Markdown(
@@ -104,7 +238,7 @@ def jupyter(info, include="friendly_tb"):  # pragma: no cover
                 display(HTML(text))
             elif item == "suggest":
                 text = html_escape(info[item])
-                display(HTML(f"<p><i>{text}<i><p>"))
+                display(HTML(f"<p><i>{text}</i></p>"))
             else:
                 text = html_escape(info[item])
                 if "header" in item:
